from django.contrib.gis.db import models

'''
class State(models.Model):
    name = models.CharField(max_length=255)
    polygon = models.PolygonField(null=True)

    def __unicode__(self):
        return self.name
'''

class Station(models.Model):
    data_id = models.IntegerField() #id in the source data
    code = models.CharField(max_length=10, unique=True, db_index=True)
    name = models.CharField(max_length=255)
    zone = models.CharField(max_length=10)
    state = models.CharField(max_length=255, blank=True)
    address = models.TextField()
    point = models.PointField(null=True)

    def __unicode__(self):
        return "%s: %s" % (self.code, self.name,)


class Train(models.Model):
    data_id = models.IntegerField()
    name = models.CharField(max_length=255)
    number = models.CharField(max_length=12, db_index=True)
    return_train = models.CharField(max_length=12, db_index=True)
    duration_h = models.IntegerField()
    duration_m = models.IntegerField()
    zone = models.CharField(max_length=10)
    date_from = models.DateField(null=True)
    date_to = models.DateField(null=True)
    from_station = models.ForeignKey(Station, related_name='trains_from')    
    to_station = models.ForeignKey(Station, related_name='trains_to')
    number_of_halts = models.IntegerField()
    typ = models.CharField(max_length=12)
    departure = models.TimeField()
    arrival = models.TimeField()
    distance = models.IntegerField()
    departure_days = models.CharField(max_length=12) #this is just a string for display, we use the booleans in our code
    monday = models.BooleanField()
    tuesday = models.BooleanField()
    wednesday = models.BooleanField()
    thursday = models.BooleanField()
    friday = models.BooleanField()
    saturday = models.BooleanField()
    sunday = models.BooleanField()
    classes = models.CharField(max_length=32)
    chair_car = models.BooleanField()
    sleeper = models.BooleanField()
    first_class = models.BooleanField()
    third_ac = models.BooleanField()
    second_ac = models.BooleanField()
    first_ac = models.BooleanField()

    def __unicode__(self):
        return "%s: %s" % (self.number, self.name,)


class Schedule(models.Model):
    data_id = models.IntegerField()
    arrival = models.TimeField() # if blank, get departure time from train models
    departure = models.TimeField()
    halt = models.IntegerField(null=True)
    stop_number = models.DecimalField(max_digits=3, decimal_places=2)
    station = models.ForeignKey(Station)
    train = models.ForeignKey(Train)
    day = models.IntegerField()
    distance_travelled = models.IntegerField()
    
    def __unicode__(self):
        return "%d: %s at %s" % (self.stop_number, self.train.name, self.station.name,)
# Create your models here.
